@@ -2,10 +2,10 @@ import pandas as pd
 from datetime import datetime, timedelta
 from typing import Union
 
-from synthetic_sample import sample_curve
-from synthetic_sample.sample_curve import SampleCurve, CustomSampleCurve
-# import sample_curve
-# from sample_curve import SampleCurve, CustomSampleCurve
+# from synthetic_sample import calculation_utils
+# from synthetic_sample.sample_curve import SampleCurve, CustomSampleCurve, PeriodType
+import calculation_utils
+from sample_curve import SampleCurve, CustomSampleCurve, PeriodType
 
 
 def create_yearly_metadata_dict(period_definition: Union[tuple, list], total_sales: int, annual_growth_rate: float) -> dict:
@@ -87,9 +87,16 @@ def apply_curve_to_time_period(curve: CustomSampleCurve, period_definition: Unio
     return sales_df.reset_index(drop=True)
 
 
-def generate_synthetic_curves(period_type: sample_curve.PeriodType, period_definition: Union[tuple, list],
-                              annual_growth_factor: float, curve_definition: dict, seasonal_distribution: dict,
-                              total_sales: int, packages_per_sale: float, quantity_per_sale: float, curve_modifiers: list) -> pd.DataFrame:
+def generate_synthetic_curves(
+        period_type: PeriodType,
+        period_definition: Union[tuple, list],
+        annual_growth_factor: float,
+        curve_definition: dict,
+        seasonal_distribution: dict,
+        total_sales: int,
+        total_packages: int,
+        total_quantity: int,
+        curve_modifiers: list) -> pd.DataFrame:
     """ Generates synthetic sales data for given json input
 
     Args:
@@ -99,20 +106,25 @@ def generate_synthetic_curves(period_type: sample_curve.PeriodType, period_defin
         curve_definition: dictionary to define the sales curve in terms of the cumulative percentage at the end of each period
         seasonal_distribution: dictionary indicating redistribution of output according to seasonal trends
         total_sales: total sales for the period
-        packages_per_sale: average number of packages per sale
-        quantity_per_sale: average quantity sold per sale
+        total_packages: total number of packages
+        total_quantity: total quantity sold
 
     Returns:
         dataframe with the total number of sales, packages, and quantity for each period in the requested time period
     """
     # Create synthetic sales curve
-    custom_curve = sample_curve.CustomSampleCurve(period_type, curve_definition)
+    custom_curve = CustomSampleCurve(period_type, curve_definition)
     sales_time_series_df = apply_curve_to_time_period(custom_curve, period_definition, seasonal_distribution,
                                                       total_sales, annual_growth_factor, curve_modifiers)
     sales_time_series_df.rename(columns={SampleCurve.value_column_name: "sales"}, inplace=True)
 
     # Add derived values based on ratio
-    sales_time_series_df["packages"] = (sales_time_series_df["sales"] * packages_per_sale).apply(int)
-    sales_time_series_df["quantity"] = (sales_time_series_df["sales"] * quantity_per_sale).apply(int)
+    sales_time_series_df["packages"] = (sales_time_series_df["sales"] * (total_packages / total_sales)).apply(int)
+    sales_time_series_df["quantity"] = (sales_time_series_df["sales"] * (total_quantity / total_sales)).apply(int)
+
+    # If outputs are not exact matches to requested totals, fill in
+    sales_time_series_df = calculation_utils.realign_with_totals(sales_time_series_df, "sales", total_sales)
+    sales_time_series_df = calculation_utils.realign_with_totals(sales_time_series_df, "packages", total_packages)
+    sales_time_series_df = calculation_utils.realign_with_totals(sales_time_series_df, "quantity", total_quantity)
 
     return sales_time_series_df
