@@ -1,7 +1,7 @@
 import pandas as pd
 
-from synthetic_sample import calculation_utils
-# import calculation_utils
+# from synthetic_sample import calculation_utils
+import calculation_utils
 
 # Internal config vars for distribution definitions
 quantity_skewness = 10
@@ -12,15 +12,17 @@ package_exponential = 3
 VALUE_COLUMN = "value"
 PERIOD_COLUMN = "period"
 
+
 # TODO Add limit to number of records
-def generate_synthetic_records(sales_curve_df: pd.DataFrame, packages_per_sale: float, quantity_per_sale: float,
-                               week_distribution: dict, weekday_distribution: dict, product_distribution: dict) -> object:
+def generate_synthetic_records(
+        sales_curve_df: pd.DataFrame,
+        week_distribution: dict,
+        weekday_distribution: dict,
+        product_distribution: dict) -> object:
     """ Generates individual sales records from an aggregated curve
 
     Args:
         sales_curve_df: dataframe with the aggregate sales values for each period
-        packages_per_sale: average number of packages per sale
-        quantity_per_sale: average quantity sold per sale
         week_distribution: dictionary indicating how sales are distributed across each weekday, only relevant for monthly curves
         weekday_distribution: dictionary indicating how sales are distributed across each weekday
         product_distribution: dictionary indicating how sales are distributed across each SKU
@@ -29,6 +31,11 @@ def generate_synthetic_records(sales_curve_df: pd.DataFrame, packages_per_sale:
         dataframe with each sale as a record with the date and categories determined by provided distributions
     """
     # Preprocessing
+    total_sales = sales_curve_df["sales"].sum()
+    total_packages = sales_curve_df["packages"].sum()
+    total_quantity = sales_curve_df["quantity"].sum()
+    packages_per_sale = total_packages / total_sales
+    quantity_per_sale = total_quantity / total_sales
     quantity_per_package = quantity_per_sale / packages_per_sale
     weekday_distribution = {int(key): weekday_distribution[key] for key in weekday_distribution}
     if "week_number" in sales_curve_df.columns:
@@ -72,6 +79,10 @@ def generate_synthetic_records(sales_curve_df: pd.DataFrame, packages_per_sale:
     digits = len(str(len(sales_df)))
     sales_df["order_id"] = (sales_df["order_id"] + 10**digits).astype(str).str.zfill(digits)
 
+    # Ensure totals match
+    sales_df = calculation_utils.realign_with_totals(sales_df, "packages", total_packages)
+    sales_df = calculation_utils.realign_with_totals(sales_df, "quantity", total_quantity)
+
     # Split out records that exceed the provided ratio into separate sales lines
     count = 1
     sales_df["line_id"] = count
